.. _history:

=======
History
=======

sktime was started in April 2019 as a collaborative project between
Franz Király, Markus Löning, Anthony Bagnall and Jason Lines. In the
first year, it grew into a community-driven project with contributions
from researchers and practitioners from around the globe.

Today, sktime continues to undergo rapid development to refine its API,
while adding new features and algorithms for a range of time series
machine learning tasks. Development is supported by the original project
members, new core developers and the broader community (see
`contributors <contributors.md>`_).

If you are interested in contributing, check out our :ref:`get_involved` guide.
